﻿//Kristen Kleckner - Capstone 2015
//Last Modified May 10, 2015

using System;
using System.IO;
using System.Drawing;
using System.Windows.Forms;
using System.Collections.Generic;
using System.Runtime.Serialization.Formatters.Binary;
using System.Runtime.Serialization;
using Microsoft.Win32;
using System.Text;

namespace testabc
{
    //Tweet struct contains all of the information that can be read in from the tweets file
    struct tweet
    {
        private string date;
        private string user;
        private int retweets;
        private int favorites;
        private string text;

        //properties so we can access the various parts of the tweet struct outside of the document class
        //In the main form, we will create arrays of tweets
        public string Date
        {
            get { return date; }
            set { date = value; }
        }
        public string User
        {
            get { return user; }
            set { user = value; }
        }
        public int Retweets
        {
            get { return retweets; }
            set { retweets = value; }
        }
        public int Favorites
        {
            get { return favorites; }
            set { favorites = value; }
        }
        public string Text
        {
            get { return text; }
            set { text = value; }
        }
    };

    //word struct to keep the word and its count together
    struct word
    {
        private string text;
        private int count;

        //properties that will allow parts of the of the struct to be accessed outside of the document class
        public string Text
        {
            get { return text; }
            set { text = value; }
        }
        public int Count
        {
            get { return count; }
            set { count = value; }
        }
    };

    class Document
    {
        //private members
        private tweet[] retweets;
        private tweet[] favorites;
        private word[] top_words;
        private word[] top_hashtags;
        private word[] top_users;
        private word[] top_mentions;
        private tweet[] word_display_tweets;
        private tweet[] hashtag_display_tweets;
        private tweet[] user_display_tweets;
        private tweet[] mention_display_tweets;
        private int max_word_tweets;
        private int max_hashtag_tweets;
        private int max_user_tweets;
        private int max_mention_tweets;
        private string searched_on;
        private string total_tweets;
        private string earliest_date;
        private string latest_date;
        private string total_words;
        private string total_users;
        private string total_hashtags;
        private string total_mentions;
        private int word_uses;
        private int hashtag_uses;
        private int user_uses;
        private int mentions_uses;

        //properties so the data can be accessed outside of the document class     
        public tweet[] Retweets
        {
            get { return retweets; }
        }
        public tweet[] Favorites
        {
            get { return favorites; }
        }
        public word[] Top_Words
        {
            get { return top_words; }
        }
        public word[] Top_Hashtags
        {
            get { return top_hashtags; }
        }
        public word[] Top_Users
        {
            get { return top_users; }
        }
        public word[] Top_Mentions
        {
            get { return top_mentions; }
        }
        public tweet[] Word_Display_Tweets
        {
            get { return word_display_tweets; }
        }
        public tweet[] Hashtag_Display_Tweets
        {
            get { return hashtag_display_tweets; }
        }
        public tweet[] User_Display_Tweets
        {
            get { return user_display_tweets; }
        }
        public tweet[] Mention_Display_Tweets
        {
            get { return mention_display_tweets; }
        }
        public int Max_Word_Tweets
        {
            get { return max_word_tweets; }
        }
        public int Max_Hashtag_Tweets
        {
            get { return max_hashtag_tweets; }
        }
        public int Max_User_Tweets
        {
            get { return max_user_tweets; }
        }
        public int Max_Mention_Tweets
        {
            get { return max_mention_tweets; }
        }
        public string Total_Tweets
        {
            get { return total_tweets; }
        }
        public string Earliest_Date
        {
            get { return earliest_date; }
        }
        public string Latest_Date
        {
            get { return latest_date; }
        }
        public string Searched_On
        {
            get { return searched_on; }
        }
        public string Total_Words
        {
            get { return total_words; }
        }
        public string Total_Hashtags
        {
            get { return total_hashtags; }
        }
        public string Total_Users
        {
            get { return total_users; }
        }
        public string Total_Mentions
        {
            get { return total_mentions; }
        }
        public int Word_Uses
        {
            get { return word_uses; }
        }
        public int Hashtag_Uses
        {
            get { return hashtag_uses; }
        }
        public int User_Uses
        {
            get { return user_uses; }
        }
        public int Mention_Uses
        {
            get { return mentions_uses; }
        }

        /***********************
        Name: Document
        Parameters: None
        Returns: None
        Purpose: Initialize the arrays and variables
        ***********************/
        public Document()
        {
            retweets = new tweet[15];
            favorites = new tweet[15];
            top_words = new word[15];
            top_hashtags = new word[15];
            top_users = new word[15];
            top_mentions = new word[15];
            word_display_tweets = new tweet[15];
            hashtag_display_tweets = new tweet[15];
            user_display_tweets = new tweet[15];
            mention_display_tweets = new tweet[15];
            total_tweets = "";
            total_users = "";
            total_words = "";
            total_hashtags = "";
            total_mentions = "";
            earliest_date = "";
            latest_date = "";
            searched_on = "";
        }

        /***********************
        Name: GetRetweetFileData
        Parameters: None
        Returns: True if everything worked, false if something went wrong
        Purpose: Open the retweet file, read the data, and set the retweets array
        ***********************/
        public bool GetRetweetFileData()
        {
            //declare and initialize variables for reading the text file
            string[] text;
            int[] file_line = new int[15];
            int index = 0;
            int count = 0;
            string line;

            //get retweet file information
            try
            {
                //open the file
                using (StreamReader sr = new StreamReader("Data/retweets.txt"))
                {
                    //read one line
                    line = sr.ReadLine();

                    //run 15 times
                    while (index < 15)
                    {
                        //data will come in as: line number, total retweets
                        //split on the comma
                        text = line.Split(',');

                        //set the index of file_line array to the line number
                        file_line[index] = Convert.ToInt32(text[0]);

                        //increment the index
                        index++;

                        //read the next line of the file
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                //display a message box if something went wrong and return false
                MessageBox.Show("Can't open retweets file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            //sort the file_line array so the line numbers are in increasing order
            Array.Sort(file_line);

            //get the tweets associated with each line number
            try
            {
                //open the file
                using (StreamReader sr = new StreamReader("Data/tweets.txt"))
                {
                    //reset the index to zero
                    index = 0;

                    //run fifteen times
                    while (index < 15)
                    {
                        //read the line
                        line = sr.ReadLine();

                        //increment the count
                        count++;

                        //if the count is the same as the value at the current index of file_line
                        if (count == file_line[index])
                        {
                            //declare a new tweet
                            tweet x = new tweet();

                            //split the line on the tabs
                            text = line.Split('\t');

                            //set the data
                            x.Date = text[0];
                            x.User = text[1];
                            x.Retweets = Convert.ToInt32(text[2]);
                            x.Favorites = Convert.ToInt32(text[3]);
                            x.Text = text[4];

                            //store the tweet in the retweets array
                            retweets[index] = x;

                            //increment the index
                            index++;
                        }
                    }

                    //Sort the array by the number of retweets so that the tweet with the most retweets is at index 0
                    Array.Sort(retweets, (y, x) => x.Retweets.CompareTo(y.Retweets));
                }
            }
            catch (Exception e)
            {
                //if something went wrong, display a message box and return false
                MessageBox.Show("Can't open tweets file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            //if everything worked correctly, return true
            return true;
        }

        /***********************
        Name: GetFavoriteFileData
        Parameters: None
        Returns: True if everything worked properly, false if something went wrong
        Purpose: Get the data from the favorite file.  The function works identically to GetRetweetFileData()
        ***********************/
        public bool GetFavoriteFileData()
        {
            string[] text;
            int[] file_line = new int[15];

            int index = 0;
            int count = 0;
            string line;

            //get retweet file information
            try
            {
                using (StreamReader sr = new StreamReader("Data/favorites.txt"))
                {
                    line = sr.ReadLine();
                    while (index < 15)
                    {
                        text = line.Split(',');
                        file_line[index] = Convert.ToInt32(text[0]);
                        index++;
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open favorites file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            Array.Sort(file_line);

            try
            {
                using (StreamReader sr = new StreamReader("Data/tweets.txt"))
                {
                    index = 0;
                    while (index < 15)
                    {
                        line = sr.ReadLine();
                        count++;
                        if (count == file_line[index])
                        {
                            tweet x = new tweet();
                            text = line.Split('\t');
                            x.Date = text[0];
                            x.User = text[1];
                            x.Retweets = Convert.ToInt32(text[2]);
                            x.Favorites = Convert.ToInt32(text[3]);
                            x.Text = text[4];
                            favorites[index] = x;
                            index++;
                        }
                    }

                    Array.Sort(favorites, (y, x) => x.Favorites.CompareTo(y.Favorites));
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open tweets file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            return true;
        }

        /***********************
        Name: GetWordFileData
        Parameters: None
        Returns: True if everything worked correctly, false if something went wrong
        Purpose: Open the word file, get the data, and store the information in the word array
        ***********************/
        public bool GetWordFileData()
        {
            //declare and initialize variables that will be used when reading the file
            string line;
            string[] text;
            string[] lineNums;
            int count = 0;

            //open and read the file
            try
            {
                using (StreamReader sr = new StreamReader("Data/words.txt"))
                {
                    //line will come in as word *tab* line numbers containing the word in a comma delimited list

                    //read the first line
                    line = sr.ReadLine();

                    //read 15 lines
                    while (count < 15)
                    {
                        //split the line on the tab
                        text = line.Split('\t');

                        //declare a new word
                        word x = new word();

                        //set the values of the word
                        x.Text = text[0];

                        //store the line numbers in an array
                        lineNums = text[1].Split(',');

                        //count is the length of the line numbers of array
                        x.Count = lineNums.Length;

                        //store the word in the top_words array
                        top_words[count] = x;

                        //increment the count
                        count++;

                        //read the next line
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                //if something went wrong, display a message box and return false
                MessageBox.Show("Can't open words file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            //if everything worked correctly, return true
            return true;
        }

        /***********************
        Name: GetUserFileData
        Parameters: None
        Returns: True if everything worked properly, false if something went wrong
        Purpose: Read the data from the user file and set the appropriate arrays; works similar to GetWordFileData()
        ***********************/
        public bool GetUserFileData()
        {
            string line;
            string[] text;
            string[] lineNums;
            int count = 0;
            try
            {
                using (StreamReader sr = new StreamReader("Data/users.txt"))
                {
                    line = sr.ReadLine();
                    while (count < 15)
                    {
                        text = line.Split('\t');
                        word x = new word();
                        x.Text = text[0];
                        lineNums = text[1].Split(',');
                        x.Count = lineNums.Length;
                        top_users[count] = x;
                        count++;
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open users file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            return true;
        }

        /***********************
        Name: GetHashtagFileData
        Parameters: none
        Returns: True if everything worked properly, false if something went wrong
        Purpose: Get the information from the hashtag file; Works similar to GetWordFileData
        ***********************/
        public bool GetHashtagFileData()
        {
            string line;
            string[] text;
            string[] lineNums;
            int count = 0;
            try
            {
                using (StreamReader sr = new StreamReader("Data/hashtags.txt"))
                {

                    line = sr.ReadLine();
                    while (count < 15)
                    {
                        text = line.Split('\t');
                        word x = new word();
                        x.Text = text[0];
                        lineNums = text[1].Split(',');
                        x.Count = lineNums.Length;
                        top_hashtags[count] = x;
                        count++;
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open hashtag file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            return true;
        }

        /***********************
        Name: GetMentionFileData
        Parameters: none
        Returns: True if everything worked properly, false if something went wrong
        Purpose: Get the information from the mention file; works similar to GetWordFileData
        ***********************/
        public bool GetMentionFileData()
        {
            string line;
            string[] text;
            string[] lineNums;
            int count = 0;
            try
            {
                using (StreamReader sr = new StreamReader("Data/mentions.txt"))
                {

                    line = sr.ReadLine();
                    //MessageBox.Show(line);
                    while (count < 15)
                    {
                        text = line.Split('\t');
                        word x = new word();
                        x.Text = text[0];
                        lineNums = text[1].Split(',');
                        x.Count = lineNums.Length;
                        top_mentions[count] = x;
                        count++;
                        line = sr.ReadLine();
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open mentions file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            return true;
        }

        /***********************
        Name: GetGeneralData
        Parameters: none
        Returns: True if everything worked properly, false if something went wrong
        Purpose: Read the data from the information file
        ***********************/
        public bool GetGeneralData()
        {
            //get file information
            try
            {
                using (StreamReader sr = new StreamReader("Data/information.txt"))
                {
                    //read the lines of the file and store into the appropriate variable
                    searched_on = sr.ReadLine();
                    total_tweets = sr.ReadLine();
                    earliest_date = sr.ReadLine();
                    latest_date = sr.ReadLine();
                    total_words = sr.ReadLine();
                    total_hashtags = sr.ReadLine();
                    total_users = sr.ReadLine();
                    total_mentions = sr.ReadLine();
                }
            }
            catch (Exception e)
            {
                //if something went wrong, display a message and return false
                MessageBox.Show("Can't open information file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            //if everything worked properly, return true
            return true;
        }

        /***********************
        Name: GetRandomWordTweets
        Parameters: the word that we are searching for
        Returns: true if everything worked properly, false if something went wrong
        Purpose: Get 15 random examples of the word provided
        ***********************/
        public bool GetRandomWordTweets(string word)
        {
            //declare and initialize variables to be used 
            string line;
            string[] text;
            string[] lineNums;
            int[] tweets;
            Random rnd;
            rnd = new Random();
            tweets = new int[15];
            try
            {
                using (StreamReader sr = new StreamReader("Data/words.txt"))
                {
                    //an extremely convoluted way of getting around error cs0165: use of unassigned local variable linenums
                    //will first assign something to linenums, even if it's the right data because otherwise the code won't compile
                    //we know that the word will be somehwere in the file, so we can guarantee that if the first line doesn't have the info we are looking for,
                    //it will be in one of the other lines
                    line = sr.ReadLine();
                    text = line.Split('\t');
                    lineNums = text[1].Split(',');

                    //if the word we want is not the first word
                    if (text[0] != word)
                    {
                        //read through the file
                        while (line != "")
                        {
                            //split the line
                            text = line.Split('\t');

                            //check if it's the word you are looking for
                            if (text[0] == word)
                            {
                                //if it is, get the list of line numbers and store it in an array and break
                                lineNums = text[1].Split(',');
                                break;
                            }

                            //else, read the next line
                            line = sr.ReadLine();
                        }
                    }

                    word_uses = lineNums.Length;

                    //if the number of entries in the array is less than 15, set max to the length of the array
                    //else set it to 15
                    //this will be how many tweets we can display
                    if (lineNums.Length < 15)
                        max_word_tweets = lineNums.Length;
                    else
                        max_word_tweets = 15;

                    //if we need 15 tweets
                    if (max_word_tweets == 15)
                    {
                        bool done;

                        //for each tweet
                        for (int i = 0; i < max_word_tweets; i++)
                        {
                            //get a value at a random index
                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);

                            //make sure the value isn't already in the array
                            if (i != 0)
                            {
                                done = false;
                                while (!done)
                                {
                                    for (int j = 0; j < i; j++)
                                    {
                                        //if it is the same as something else, reassign the value
                                        if (tweets[j] == tweets[i])
                                        {
                                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);

                                            //switch done to false to verify it didn't pick something else that was already in the array
                                            done = false;
                                            break;
                                        }
                                        else
                                            done = true;
                                    }
                                }
                            }
                        }

                        //sort the line numbers in increasing order
                        Array.Sort(tweets);
                    }
                    //if we need less than 15 tweets
                    else
                    {
                        //get the line numbers directly from the lineNums array that was read in from the file
                        for (int i = 0; i < max_word_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[i]);
                        }
                    }

                    //open the tweets file to read 
                    try
                    {
                        using (StreamReader tr = new StreamReader("Data/tweets.txt"))
                        {
                            //initialize variables
                            int index = 0;
                            int count = 1;  //line numbers start at 1
                            string[] line_tweet;

                            //until we have gathered all of the tweets we need
                            while (index < max_word_tweets)
                            {
                                //read a line
                                line = tr.ReadLine();

                                //if the line number we need is the same as what is stored at index of tweets
                                if (count == tweets[index])
                                {
                                    //create a new tweet
                                    tweet x = new tweet();

                                    //split on tabs
                                    line_tweet = line.Split('\t');

                                    //store the data in the tweet
                                    x.Date = line_tweet[0];
                                    x.User = line_tweet[1];
                                    x.Retweets = Convert.ToInt32(line_tweet[2]);
                                    x.Favorites = Convert.ToInt32(line_tweet[3]);
                                    x.Text = line_tweet[4];

                                    //add the tweet to the array of tweets to be displayed
                                    word_display_tweets[index] = x;

                                    //increment index
                                    index++;
                                }

                                //increment count
                                count++;
                            }
                        }
                    }
                    catch (Exception w)
                    {
                        //if something went wrong, display a message and return false
                        MessageBox.Show("Can't open tweets file\r\n" + w.Message, Application.ProductName);
                        return false;
                    }
                }
            }
            catch (Exception e)
            {
                //if something went wrong, display a message and return false
                MessageBox.Show("Can't open words file\r\n" + e.Message, Application.ProductName);
                return false;
            }

            //if everything worked properly, return true
            return true;
        }

        /***********************
        Name: GetRandomHashtagTweets
        Parameters: hashtag to search for
        Returns: true if everything worked properly, false if something went wrong
        Purpose: Get examples of uses of the hashtag searched on; works similar to GetRandomWordTweets
        ***********************/
        public bool GetRandomHashtagTweets(string hashtag)
        {
            string line;
            string[] text;
            string[] lineNums;
            int[] tweets;
            Random rnd;
            rnd = new Random();
            tweets = new int[15];
            try
            {
                using (StreamReader sr = new StreamReader("Data/hashtags.txt"))
                {
                    //an extremely convoluted way of getting around error cs0165: use of unassigned local variable linenums
                    //will first assign something to linenums, even if it's the right data because otherwise the code won't compile
                    //we know that the word will be somehwere in the file, so we can guarantee that if the first line doesn't have the info we are looking for,
                    //it will be in one of the other lines
                    line = sr.ReadLine();
                    text = line.Split('\t');
                    lineNums = text[1].Split(',');
                    if (text[0] != hashtag)
                    {
                        while (line != "")
                        {
                            text = line.Split('\t');
                            if (text[0] == hashtag)
                            {
                                lineNums = text[1].Split(',');
                                break;
                            }
                            line = sr.ReadLine();
                        }
                    }

                    hashtag_uses = lineNums.Length;

                    if (lineNums.Length < 15)
                        max_hashtag_tweets = lineNums.Length;
                    else
                        max_hashtag_tweets = 15;

                    if (max_hashtag_tweets == 15)
                    {
                        bool done;

                        for (int i = 0; i < max_hashtag_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);

                            //make sure the value isn't already in the array
                            if (i != 0)
                            {
                                done = false;
                                while (!done)
                                {
                                    for (int j = 0; j < i; j++)
                                    {
                                        //if it is the same as something else, reassign the value
                                        if (tweets[j] == tweets[i])
                                        {
                                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);
                                            done = false;
                                            break;
                                        }
                                        else
                                            done = true;
                                    }
                                }
                            }
                        }
                        Array.Sort(tweets);
                    }
                    else
                    {
                        for (int i = 0; i < max_hashtag_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[i]);
                        }
                    }

                    try
                    {
                        using (StreamReader tr = new StreamReader("Data/tweets.txt"))
                        {
                            int index = 0;
                            int count = 1;  //line numbers start at 1
                            string[] line_tweet;
                            while (index < max_hashtag_tweets)
                            {
                                line = tr.ReadLine();
                                if (count == tweets[index])
                                {
                                    tweet x = new tweet();
                                    line_tweet = line.Split('\t');
                                    x.Date = line_tweet[0];
                                    x.User = line_tweet[1];
                                    x.Retweets = Convert.ToInt32(line_tweet[2]);
                                    x.Favorites = Convert.ToInt32(line_tweet[3]);
                                    x.Text = line_tweet[4];
                                    hashtag_display_tweets[index] = x;
                                    index++;
                                }
                                count++;
                            }
                        }
                    }
                    catch (Exception w)
                    {
                        MessageBox.Show("Can't open tweets file\r\n" + w.Message, Application.ProductName);
                        return false;
                    }

                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open hashtag file\r\n" + e.Message, Application.ProductName);
                return false;
            }
            return true;
        }

        /***********************
        Name: GetRandomUserTweets
        Parameters: user to search for
        Returns: true if everything worked properly, false if something went wrong
        Purpose: Get examples of uses of the user searched on; works similar to GetRandomWordTweets
        ***********************/
        public bool GetRandomUserTweets(string username)
        {
            string line;
            string[] text;
            string[] lineNums;
            int[] tweets;
            Random rnd;
            rnd = new Random();
            tweets = new int[15];
            try
            {
                using (StreamReader sr = new StreamReader("Data/users.txt"))
                {
                    line = sr.ReadLine();
                    text = line.Split('\t');
                    lineNums = text[1].Split(',');
                    if (text[0] != username)
                    {
                        while (line != "")
                        {
                            text = line.Split('\t');
                            if (text[0] == username)
                            {
                                lineNums = text[1].Split(',');
                                break;
                            }
                            line = sr.ReadLine();
                        }
                    }

                    user_uses = lineNums.Length;

                    if (lineNums.Length < 15)
                        max_user_tweets = lineNums.Length;
                    else
                        max_user_tweets = 15;

                    if (max_user_tweets == 15)
                    {
                        bool done;

                        for (int i = 0; i < max_user_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);

                            //make sure the value isn't already in the array
                            if (i != 0)
                            {
                                done = false;
                                while (!done)
                                {
                                    for (int j = 0; j < i; j++)
                                    {
                                        //if it is the same as something else, reassign the value
                                        if (tweets[j] == tweets[i])
                                        {
                                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);
                                            done = false;
                                            break;
                                        }
                                        else
                                            done = true;
                                    }
                                }
                            }
                        }

                        Array.Sort(tweets);
                    }
                    else
                    {
                        for (int i = 0; i < max_user_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[i]);
                        }
                    }

                    try
                    {
                        using (StreamReader tr = new StreamReader("Data/tweets.txt"))
                        {
                            int index = 0;
                            int count = 1;  //line numbers start at 1
                            string[] line_tweet;
                            while (index < 15)
                            {
                                line = tr.ReadLine();
                                if (count == tweets[index])
                                {
                                    tweet x = new tweet();
                                    line_tweet = line.Split('\t');
                                    x.Date = line_tweet[0];
                                    x.User = line_tweet[1];
                                    x.Retweets = Convert.ToInt32(line_tweet[2]);
                                    x.Favorites = Convert.ToInt32(line_tweet[3]);
                                    x.Text = line_tweet[4];
                                    user_display_tweets[index] = x;
                                    index++;
                                }
                                count++;
                            }
                        }
                    }
                    catch (Exception w)
                    {
                        MessageBox.Show("Can't open tweets file\r\n" + w.Message, Application.ProductName);
                        return false;
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open users file\r\n" + e.Message, Application.ProductName);
                return false;
            }
            return true;
        }

        /***********************
        Name: GetRandomMentionTweets
        Parameters: username to search for
        Returns: true if everything worked properly, false if something went wrong
        Purpose: Get examples of uses of the user searched on; works similar to GetRandomWordTweets
        ***********************/
        public bool GetRandomMentionTweets(string username)
        {
            string line;
            string[] text;
            string[] lineNums;
            int[] tweets;
            Random rnd;
            rnd = new Random();
            tweets = new int[15];
            try
            {
                using (StreamReader sr = new StreamReader("Data/mentions.txt"))
                {
                    //an extremely convoluted way of getting around error cs0165: use of unassigned local variable linenums
                    //will first assign something to linenums, even if it's the right data because otherwise the code won't compile
                    //we know that the word will be somehwere in the file, so we can guarantee that if the first line doesn't have the info we are looking for,
                    //it will be in one of the other lines
                    line = sr.ReadLine();
                    text = line.Split('\t');
                    lineNums = text[1].Split(',');
                    if (text[0] != username)
                    {
                        while (line != "")
                        {
                            text = line.Split('\t');
                            if (text[0] == username)
                            {
                                lineNums = text[1].Split(',');
                                break;
                            }
                            line = sr.ReadLine();
                        }
                    }

                    mentions_uses = lineNums.Length;

                    if (lineNums.Length < 15)
                        max_mention_tweets = lineNums.Length;
                    else
                        max_mention_tweets = 15;

                    if (max_mention_tweets == 15)
                    {
                        bool done;

                        for (int i = 0; i < 15; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);

                            //make sure the value isn't already in the array
                            if (i != 0)
                            {
                                done = false;
                                while (!done)
                                {
                                    for (int j = 0; j < i; j++)
                                    {
                                        //if it is the same as something else, reassign the value
                                        if (tweets[j] == tweets[i])
                                        {
                                            tweets[i] = Convert.ToInt32(lineNums[rnd.Next(lineNums.Length)]);
                                            done = false;
                                            break;
                                        }
                                        else
                                            done = true;
                                    }
                                }
                            }
                        }
                        Array.Sort(tweets);
                    }
                    else
                    {
                        for (int i = 0; i < max_mention_tweets; i++)
                        {
                            tweets[i] = Convert.ToInt32(lineNums[i]);
                        }
                    }

                    try
                    {
                        using (StreamReader tr = new StreamReader("Data/tweets.txt"))
                        {
                            int index = 0;
                            int count = 1;  //line numbers start at 1
                            string[] line_tweet;
                            while (index < 15)
                            {
                                line = tr.ReadLine();
                                if (count == tweets[index])
                                {
                                    tweet x = new tweet();
                                    line_tweet = line.Split('\t');
                                    x.Date = line_tweet[0];
                                    x.User = line_tweet[1];
                                    x.Retweets = Convert.ToInt32(line_tweet[2]);
                                    x.Favorites = Convert.ToInt32(line_tweet[3]);
                                    x.Text = line_tweet[4];
                                    mention_display_tweets[index] = x;
                                    index++;
                                }
                                count++;
                            }
                        }
                    }
                    catch (Exception w)
                    {
                        MessageBox.Show("Can't open tweets file\r\n" + w.Message, Application.ProductName);
                        return false;
                    }
                }
            }
            catch (Exception e)
            {
                MessageBox.Show("Can't open mentions file\r\n" + e.Message, Application.ProductName);
                return false;
            }
            return true;
        }
    }
}
